# Hopfield-NLMIP

[![Build Status](https://travis-ci.com/mathildebadoual/Hopfield-NLMIP.svg?token=sSNFwE8cjSB4sGxziMoY&branch=master)](https://travis-ci.org/mathildebadoual/Hopfield-NLMIP)  [![codecov](https://codecov.io/gh/mathildebadoual/Hopfield-NLMIP/branch/master/graph/badge.svg?token=bf241da9-a152-4025-baa6-60013f5f2a85)](https://codecov.io/gh/mathildebadoual/Hopfield-NLMIP)

Solver for large scale nonlinear mixed integer problems.
